# OpenEI data

This directory contains the *agents profiles* in a binary format
([npz](https://numpy.org/doc/stable/reference/generated/numpy.savez.html)).

These profiles have been created by using real data of energy consumption,
from an [OpenEI dataset](https://doi.org/10.25984/1788456), publicly accessible
under license CC-BY-4.0.

For more details about *agents profiles*, please see the documentation for
`smartgrid.agents.profile.agent_profile`.
